==> tabular-model-3.0.0-20140319.135457-46-sources.jar: org/gcube/data/analysis/tabulardata/expression/composite/arithmetic/Subtraction.java <==
package org.gcube.data.analysis.tabulardata.expression.composite.arithmetic;

import javax.xml.bind.annotation.XmlRootElement;

import org.gcube.data.analysis.tabulardata.expression.Expression;
import org.gcube.data.analysis.tabulardata.expression.MalformedExpressionException;
import org.gcube.data.analysis.tabulardata.expression.Operator;
import org.gcube.data.analysis.tabulardata.expression.composite.BinaryExpression;
import org.gcube.data.analysis.tabulardata.model.datatype.DataType;
import org.gcube.data.analysis.tabulardata.model.datatype.NumericType;
import org.gcube.data.analysis.tabulardata.model.datatype.TextType;
@XmlRootElement
public class Subtraction extends BinaryExpression {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1256644830788961321L;

	@SuppressWarnings("unused")
	private Subtraction() {}

	public Subtraction(Expression leftArgument, Expression rightArgument) {
		super(leftArgument, rightArgument);	
	}

	@Override
	public Operator getOperator() {		
		return Operator.SUBTRACTION;
	}
	
	@Override
	public DataType getReturnedDataType() throws MalformedExpressionException {
		DataType left=getLeftArgument().getReturnedDataType();
		DataType right=getRightArgument().getReturnedDataType();
		if(left==right) return left;
		if(left instanceof TextType||right instanceof TextType) return new TextType();
		if(left instanceof NumericType||right instanceof NumericType) return new NumericType();
		throw new MalformedExpressionException("Left argument "+left+" and right argument "+right+" are not compatible for "+getOperator());
	}
}

==> tabular-model-3.0.3-20140326.164338-1-sources.jar: org/gcube/data/analysis/tabulardata/expression/composite/arithmetic/Subtraction.java <==
package org.gcube.data.analysis.tabulardata.expression.composite.arithmetic;

import javax.xml.bind.annotation.XmlRootElement;

import org.gcube.data.analysis.tabulardata.expression.Expression;
import org.gcube.data.analysis.tabulardata.expression.NotEvaluableDataTypeException;
import org.gcube.data.analysis.tabulardata.expression.Operator;
import org.gcube.data.analysis.tabulardata.expression.composite.BinaryExpression;
import org.gcube.data.analysis.tabulardata.model.datatype.DataType;
import org.gcube.data.analysis.tabulardata.model.datatype.NumericType;
import org.gcube.data.analysis.tabulardata.model.datatype.TextType;
@XmlRootElement
public class Subtraction extends BinaryExpression {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1256644830788961321L;

	@SuppressWarnings("unused")
	private Subtraction() {}

	public Subtraction(Expression leftArgument, Expression rightArgument) {
		super(leftArgument, rightArgument);	
	}

	@Override
	public Operator getOperator() {		
		return Operator.SUBTRACTION;
	}
	
	@Override
	public DataType getReturnedDataType() throws NotEvaluableDataTypeException{
		DataType left=getLeftArgument().getReturnedDataType();
		DataType right=getRightArgument().getReturnedDataType();
		if(left==right) return left;
		if(left instanceof TextType||right instanceof TextType) return new TextType();
		if(left instanceof NumericType||right instanceof NumericType) return new NumericType();
		throw new NotEvaluableDataTypeException("Left argument "+left+" and right argument "+right+" are not compatible for "+getOperator());
	}
}
